@@ -229,7 +229,7 @@ public class ConflictHandler {
                         li = new ArrayList<CalendarDataObject>();
                     }
 
-                    if ((create || cdao.getObjectID() != conflict_dao.getObjectID())) { // Same id should never conflict if we are running an update
+                    if (shouldConflict(cdao, conflict_dao)) { // Same id should never conflict if we are running an update
                         if (!conflict_dao.containsRecurrencePosition()) {
                             if (!recColl.checkMillisInThePast(conflict_dao.getEndDate().getTime())) {
                                 li.add(conflict_dao);
@@ -277,6 +277,22 @@ public class ConflictHandler {
             }
         }
     }
+    
+    boolean shouldConflict(CalendarDataObject cdao, CalendarDataObject conflictDao) {
+        if (create) {
+            return true;
+        }
+        if (cdao.containsRecurrenceID() && cdao.getRecurrenceID() == conflictDao.getObjectID()) {
+            return false;
+        }
+        if (conflictDao.containsRecurrenceID() && conflictDao.getRecurrenceID() == cdao.getObjectID()) {
+            return false;
+        }
+        if (cdao.getObjectID() != conflictDao.getObjectID()) {
+            return true;
+        }
+        return false;
+    }
 
     private List<UserParticipant> getConflictUsers() {
         List<UserParticipant> relevantUsers = new ArrayList<UserParticipant>();
